#!/bin/bash
## -- FILE ------------------------------------------------------------------
## name       : bzjavaw.sh
## project    : BoarderZone: Applications
## created    : Leon Poyyayil - 2015-04-02
## language   : Linux shell script
## environment: GNU bash 2.05b.0
## copyright  : (c) 1990-2023 by Leon Poyyayil (private), Switzerland
## license    : this is free software licensed under the GPL. see COPYING
## --------------------------------------------------------------------------


## PURPOSE:
## ========
## executes a java application with additional java specific options and thus
## provides a single point where the invocation of java can be customized for
## all BoarderZone swing applications.





BZ_JAVA_OPTS=
# BZ_JAVA_OPTS="$BZ_JAVA_OPTS -Xmx384m"
# BZ_JAVA_OPTS="$BZ_JAVA_OPTS -Djava.security.manager"
# BZ_JAVA_OPTS="$BZ_JAVA_OPTS -Djava.security.policy=`dirname "$0"`/conf/bz.policy"
# BZ_JAVA_OPTS="$BZ_JAVA_OPTS -Djava.security.debug=policy,access,failure"

## enable logging to the console if log4j.jar is missing by uncommenting the
## the line below (can be one of: log4j, jdk, console, single, none (or a fully
## qualified class name available in the classpath))
# BZ_JAVA_OPTS="$BZ_JAVA_OPTS -Dnet.boarderzone.util.LoggerFactory=console"


BZ_OS_TYPE=$(uname)
if [[ $BZ_OS_TYPE == Darwin ]]; then
  # determine application name from arguments:
  APP_DIR=
  APP_NAME=
  for CMDLINE_ARG in "$@"
  do
    if [ -f "$CMDLINE_ARG" ]; then
      APP_DIR=$(dirname "$CMDLINE_ARG")
      APP_NAME=$(basename "$CMDLINE_ARG" ".jar")
    fi
  done

  # necessary on OS-X to:
  # - option 1: get notified when the user presses Apple-Q or closes the app in the Finder menu
  # - option 2: set a display name for the running app in the dock
  # - option 3: set a display icon for the running app in the dock
  BZ_JAVA_OPTS="$BZ_JAVA_OPTS -Dapple.eawt.quitStrategy=CLOSE_ALL_WINDOWS"
  BZ_JAVA_OPTS="$BZ_JAVA_OPTS -Xdock:name=BZ-${APP_NAME}"
  BZ_JAVA_OPTS="$BZ_JAVA_OPTS -Xdock:icon=$APP_DIR/conf/${APP_NAME}32.png"
fi


(java $BZ_JAVA_OPTS "$@")&


## -- EOF -------------------------------------------------------------------
